/******************************** 
 *   DeliverGlyphs
 *   Places glyphs contained between two Glyph IDs (GIDs) in the active text block
 *
 *   EN - FR - DE
 *
 *   How to:
 *   1-Create a textFrame in your document
 *   2-Click on it with the Text tool
 *   3-Define the font whose glyphs you want to import.
 *   4-Get from the Glyphs panel the GIDs of the characters you want to import 
 *     (you can sort the glyphs by their GIDs in the panel options) 
 *   5-Run the script, specify the first and the last GID
 *   6-Click OK. That's all.
 *
 *   Author : Jean loup Fusz (Jloupf) www.jloupf.fr
 *   Version : 1.1
 *   1st released : March 2020

 *   -------------------------------------
 *    ChangeLog:
 *   -------------------------------------
 *    [1.1]
 *   - undo mode
 *   - display execution time
 *   - 30' exit
 *   - close the Glyphs panel during execution and re-open it at the end (is there a real impact on performance?)
 *   - Fix error in case of bad reading of a font's style.
 *
 *    [1.0]
 *   - First released
 *
 *
 *   Platforms tested : Mac
 *   Version tested : CS6, CC17, CC18, CC19, 2020
 *
 *   Thanks to Olav Martin Kvern and his script Insert-A-Glyph'o-matic for inspiration
 *   Many thanks to Marc Autret for the progress bar and YALT
 *   UI made with the awesome tool scriptui.joonas.me    
 *   
 *   Translations are perfectible. I am open to any suggestions for improvements.
 *
 *   Bugs & FeedBack : contact[at]jloupf[dot]fr
 */




var scriptName = "DeliverGlyphs";
var version = "1.1";
var date = "2020";

// Barre de progression — Thanks to Marc Autret
var ProgressBar = function( /*str*/ title) {
    var w = new Window('palette', ' ' + title, { x: 0, y: 0, width: 340, height: 60 }),
        pb = w.add('progressbar', { x: 20, y: 12, width: 300, height: 12 }, 0, 100),
        st = w.add('statictext', { x: 10, y: 36, width: 320, height: 20 }, '');

    st.justify = 'center';
    w.center();
    this.reset = function(msg, maxValue) {
        st.text = msg;
        pb.value = 0;
        pb.maxvalue = maxValue || 0;
        pb.visible = !!maxValue;
        w.show();
    };
    this.hit = function() {++pb.value; };
    this.hide = function() { w.hide(); };
    this.close = function() { w.close(); };
};


function main() {
    var activeFont = app.selection[0].appliedFont.fontFamily;
    try {
        var activeStyle = app.selection[0].appliedFont.fontStyleName;
    } catch (errStyle) {
        alert(__("Oops! We can't determine the style of the font used... Try another version of this font."));
        exit();
    }
    var result = myUI(activeFont, activeStyle);
    if (result) {
        app.panels.item(19).visible = false;
        beginGlyph = parseInt(result["beginGlyph"]);
        endGlyph = parseInt(result["endGlyph"]);
        totalGlyphs = endGlyph - beginGlyph + 1;
        if (true) {}
        startDelivery = new Date();
        var pBar = new ProgressBar("DeliverGlyphs");
        pBar.reset(__("Glyphs are on their way"), endGlyph - beginGlyph);
        var c = 0;
        var noMore = false;
        vaAuBout = false;
        limiteTemps = 30000;
        var debutPause = 0;
        var finDePause = 0;

        function placeGlyph() {
            try {
                replaceWithGlyphID(i, app.selection[0], activeFont, activeStyle, beginGlyph, endGlyph);
                app.selection[0].contents = " ";
                pBar.hit();
                c++;
            } catch (e) {
                pBar.close();
                noMore = true;
                endGlyph = beginGlyph + c - 1;
                endDelivery = new Date();
                timeDelivery = (endDelivery - startDelivery) / 1000;
                endScreen(c, beginGlyph, endGlyph, noMore, timeDelivery);
                exit();
            }
        }
        for (i = beginGlyph; i <= endGlyph; ++i) {
            if (vaAuBout) {
                tempTime = 0;
            } else {
                currentTime = new Date();
                tempTime = currentTime - startDelivery;
            }
            if (tempTime >= limiteTemps && !vaAuBout) {
                debutPause = new Date();
                var onContinue = continueUI(c, totalGlyphs, limiteTemps);
                if (onContinue) {
                    finDePause = new Date();
                    vaAuBout = true;
                    placeGlyph();
                } else {
                    app.panels.item(19).visible = true;
                    exit();
                }
            } else {
                placeGlyph();
            }
        }
        endDelivery = new Date();
        pauseTemps = finDePause - debutPause;
        timeDelivery = (endDelivery - startDelivery - pauseTemps) / 1000;
        app.panels.item(19).visible = true;
        endScreen(c, beginGlyph, endGlyph, noMore, timeDelivery);
    }
}

function replaceWithGlyphID(j, insertionPoint, fontNameGlyph, fontStyleGlyph, beginGlyph, endGlyph) {
    changeGlyphID = Number(j);
    var story = insertionPoint.parentStory;
    var index = insertionPoint.index;
    var minionFont = app.fonts.itemByName("Minion Pro");
    if (minionFont.isValid) {
        var minionFontStyle = "Regular";
    }
    insertionPoint.contents = " ";
    var character = story.characters.item(index);
    character.appliedFont = minionFont;
    character.fontStyle = minionFontStyle;
    spaceGlyph = 1;
    resetFindChangeGlyphPreferences();
    app.findGlyphPreferences.appliedFont = minionFont;
    app.findGlyphPreferences.fontStyle = minionFontStyle;
    app.findGlyphPreferences.glyphID = spaceGlyph;
    app.changeGlyphPreferences.appliedFont = fontNameGlyph;
    app.changeGlyphPreferences.fontStyle = fontStyleGlyph;
    app.changeGlyphPreferences.glyphID = changeGlyphID;
    character.changeGlyph();
    character = story.characters.item(index);
    resetFindChangeGlyphPreferences();
}

function resetFindChangeGlyphPreferences() {
    app.findGlyphPreferences = NothingEnum.NOTHING;
    app.changeGlyphPreferences = NothingEnum.NOTHING;
}


function myUI(activeFont, activeStyle) {

    var deliverGlyphs = new Window("dialog");
    deliverGlyphs.text = scriptName + " " + version;
    deliverGlyphs.orientation = "row";
    deliverGlyphs.alignChildren = ["center", "top"];
    deliverGlyphs.spacing = 10;
    deliverGlyphs.margins = 16;

    var colGauche = deliverGlyphs.add("group", undefined, { name: "colGauche" });
    colGauche.orientation = "column";
    colGauche.alignChildren = ["left", "center"];
    colGauche.spacing = 10;
    colGauche.margins = 0;

    var policeActive = colGauche.add("panel", undefined, undefined, { name: "PoliceActive" });
    policeActive.text = __("Active font: ");
    policeActive.preferredSize.width = 400;
    policeActive.orientation = "column";
    policeActive.alignChildren = ["left", "top"];
    policeActive.spacing = 10;
    policeActive.margins = [10, 20, 10, 10];

    var familleeDePoliceGroup = policeActive.add("group", undefined, { name: "familleeDePoliceGroup" });
    familleeDePoliceGroup.orientation = "row";
    familleeDePoliceGroup.alignChildren = ["left", "center"];
    familleeDePoliceGroup.spacing = 10;
    familleeDePoliceGroup.margins = 0;

    var familleDePolicesLabel = familleeDePoliceGroup.add("statictext", undefined, undefined, { name: "familleDePolicesLabel" });
    familleDePolicesLabel.text = __("Font family: ");

    var familleDePolices = familleeDePoliceGroup.add("statictext", undefined, undefined, { name: "familleDePolices" });
    familleDePolices.text = activeFont;

    var styleDePoliceGroupe = policeActive.add("group", undefined, { name: "styleDePoliceGroupe" });
    styleDePoliceGroupe.orientation = "row";
    styleDePoliceGroupe.alignChildren = ["left", "center"];
    styleDePoliceGroupe.spacing = 10;
    styleDePoliceGroupe.margins = 0;

    var styleDePoliceLabel = styleDePoliceGroupe.add("statictext", undefined, undefined, { name: "styleDePoliceLabel" });
    styleDePoliceLabel.text = __("Font style: ");

    var styleDePolice = styleDePoliceGroupe.add("statictext", undefined, undefined, { name: "styleDePolice" });
    styleDePolice.text = activeStyle;

    var divider1 = policeActive.add("panel", undefined, undefined, { name: "divider1" });
    divider1.alignment = "fill";

    var premierGlyphIDGroup = policeActive.add("group", undefined, { name: "PremierGlyphIDGroup" });
    premierGlyphIDGroup.orientation = "row";
    premierGlyphIDGroup.alignChildren = ["left", "center"];
    premierGlyphIDGroup.spacing = 10;
    premierGlyphIDGroup.margins = 0;

    var premierGlyphIDLabel = premierGlyphIDGroup.add("statictext", undefined, undefined, { name: "PremierGlyphIDLabel" });
    premierGlyphIDLabel.text = __("First Glyph ID:");

    var premierGlyphID = premierGlyphIDGroup.add('edittext {properties: {name: "PremierGlyphID"}}');
    premierGlyphID.helpTip = __("Specify the starting GID");
    premierGlyphID.text = "1";
    premierGlyphID.preferredSize.width = 80;

    var dernierGlyphIDGroup = policeActive.add("group", undefined, { name: "DernierGlyphIDGroup" });
    dernierGlyphIDGroup.orientation = "row";
    dernierGlyphIDGroup.alignChildren = ["left", "center"];
    dernierGlyphIDGroup.spacing = 10;
    dernierGlyphIDGroup.margins = 0;

    var dernierGlyphIDLabel = dernierGlyphIDGroup.add("statictext", undefined, undefined, { name: "DernierGlyphIDLabel" });
    dernierGlyphIDLabel.text = __("Last Glyph ID:");

    var dernierGlyphID = dernierGlyphIDGroup.add('edittext {properties: {name: "DernierGlyphID"}}');
    dernierGlyphID.helpTip = __("Specify the end GID");
    dernierGlyphID.text = "100";
    dernierGlyphID.preferredSize.width = 80;

    var signatureGroupe = colGauche.add("group", undefined, { name: "signatureGroupe" });
    signatureGroupe.orientation = "row";
    signatureGroupe.alignChildren = ["left", "bottom"];
    signatureGroupe.spacing = 10;
    signatureGroupe.margins = [10, 0, 0, 0];

    var logoImage_imgString = "%C2%89PNG%0D%0A%1A%0A%00%00%00%0DIHDR%00%00%00(%00%00%00%1A%08%06%00%00%00%C3%85L%1E%C3%8B%00%00%02%C2%B0IDATX%C2%85%C3%8D%C2%97%5B%C2%88MQ%18%C3%87%7F%C3%A7%C3%A4%C2%92%0Cr%2B)b%5E%C2%BC%11g%1E4O%C3%A4%C2%92%3Cx%12)%C3%A5%C3%81%C3%A5%C2%94%12%C2%A2%26%24%2F%13%C3%B2%22%24%1D%09%C3%B1%C2%A0h%C3%A6E%123.II%C2%8EH)%C3%91%C2%A0%C2%94%24%C2%971%0A%C2%8D%C3%8B%C3%91%C2%A7%C3%BF%C2%A9%C3%95%C2%99%C2%B5%C3%B7Zg%C3%8E%0E%C3%BF%C3%9A%C3%AD%C2%BD%C3%97%5E%C3%9F%C2%B7%C3%BE%C3%BB%5B%C3%9Fm%C3%A5%08c)%C3%90%06%C2%8C%C2%89%C2%98%1B%C2%83~%C3%A02%C2%B0'fr%0C%C3%81n%C3%A0%3Dp'%23%C2%82%C3%A3%C2%80%C3%9D%C3%80T%C3%A0U%16%0A%C2%AF%03k%C2%B2P%24L%03*%C2%BAg%C2%82%C2%B9%C3%80%C3%B8%7FEp%08%C3%90%04l%06%C2%86%C2%A6%C3%8C%5B%C2%A2%7B'%C3%B0(%1B%C2%9Eq0%C2%82%C2%A3%C2%81%C3%B9z%0E%C3%A1%C3%81%C3%9F%26%C2%98%056%00%C3%A7%C2%B5m%C3%AE%C3%95%C2%93%C2%A0%C2%BB%C3%AE-n%04%C2%96~%16%02E%60%05%C3%90%2C%C2%B2%C2%86%C3%A7%01%C2%BD%C2%8B%C2%81%C2%B7%C2%9Eq%0B%C3%8A%3E%C2%9F%40%3B%C3%90%1B%C2%B8%C2%8A%C3%8E%7C%23c%C2%96%18%C3%AB%C2%8C%C3%B5h%C2%BC%0B%C3%98%C2%9F%40%C2%ACj%C3%81%3E%C3%8FZ%C3%9F%C2%80sI%16%3C%01%C2%94%03%7F%C3%AD%C3%A6%C3%82%C2%82%C3%AEF%C3%B0%C2%A3%C2%B6%C2%BA%5B%C2%96k%C3%96s%1Af%02%2Fk%C2%BE%C2%B7%00w%C2%81%C2%A3%C3%80%C3%AD%C2%80%7C%10F%C2%B0%C3%ACX%C2%B0%C3%AC%C2%906%0B%C2%96%12%14%C2%84%7C%C3%B0%C2%B4t%C3%A5I%C2%A8%24%C3%B6gs%12%C2%84o%25%C3%B8V%C3%81c%C3%BD%C3%A35.%C3%A1%12%7C%01L%C3%B7X%C3%900%19x%0Al%02N%C3%B9H%C3%AC%C2%94%C2%A0%C3%AFZ%C2%9D%40%C2%BC%C2%A4%C2%80q%C3%9F%C2%93%C3%9C%25%26%C2%8Aw%01o%C2%80Q)s%C2%A2Q%C3%90%C2%96%C2%BAhc%60%00%C3%95Cp%C2%84%C2%8C%C2%B37%C2%86%C3%84%C3%81%04%C3%8BY%20%C2%94%C2%B5%C3%98%07%C2%BDWQ%C3%90x%C3%89%C3%B1%C3%8Bz%08%1Av%00%0Fc%C3%B2%C3%A0l%C3%A0%C2%93g%C3%9C%7C%C2%B1%25A%C3%A6~d%C2%A7%C2%94%C2%86%C2%AFT%23%C3%A5%7FF%C2%A3%04%C3%B3%C2%8A%C2%BA%C2%A6A%C3%88%0E%C3%93%C3%AEX%25%C2%9A%C2%90%C2%B6%C3%80%60%60%C3%8A%0F%C2%A8%1AXJ%C3%B8l%C3%BE%02%C2%B4%C3%96%C2%A1%C3%8B%C2%92%C3%BE%3D%C3%A0%12%C3%B0%1A%C3%98%C3%A7s%C2%8B%18%C2%82%15%11r%C3%91%C2%AE%26v%C2%99%C2%ACg%C3%91z%13%C2%B8%C2%A2N9%0D%13%C3%B5%C3%AD%C2%90%3A%C2%A9%C2%91%C3%80Z%60%0B%C2%B0%5D%C3%9Fr%C2%B2n%7F%C2%8C%23%C2%9B%C2%A5V%02%C3%9B%C2%80%1F%12%3E%2B%C2%82%1D%C3%8E%C2%BC%C2%9C%C3%93%C2%8Eu%C2%A6%C3%A8%5B%07%7CQs%C3%A1%C3%82%C3%B2%C3%AFV%C3%A0%0C0O%05cy%04%C2%BF%3F%C3%89%C2%B2C%C3%B5%C2%B6W%C3%9BYq%2C%C3%A1%C3%A20%C3%B0%3D%C3%90p%C3%BC%026zd%5B%C2%A5%C2%B7Kzf%C3%85%C2%90%C3%B3a%C2%92%14%C2%99s%C3%97%C3%A2%1Ap2%20o%C3%A5%C3%B2%C2%98g%C2%BC%C2%A8%C3%83Y%26%C2%B8%0A%3C%03fHY%C3%9E%C2%A9%1E%0B%02%0B%C2%AC%C2%97%C2%95W9cv%C3%AEy'w%C3%8A%04S%14%C2%BD%3F%C2%81%C3%87%C2%AA%C2%9BF%C3%8E%C2%8E%C2%93!%C2%98%C2%AF%1E%C3%91%7C%2BgO%C3%B4%7C%11%18%5E%2B%C3%9CH%C2%B6%C2%B7zi%25%C3%90%C2%AA%C2%89%C3%B9%C3%A7%05U%C2%90XX%09%5C%C2%A4%C3%83%C2%9A%C3%B5~7%06%08%02%C2%BF%01W%18%C2%AA%C2%B1%C3%BB%C3%8Ak%C2%94%00%00%00%00IEND%C2%AEB%60%C2%82";
    if (parseInt(app.version) > 8) {
        var ui = app.generalPreferences.uiBrightnessPreference;
        if (ui < 0.51) {
            var logoImage_imgString = "%C2%89PNG%0D%0A%1A%0A%00%00%00%0DIHDR%00%00%00(%00%00%00%1A%08%06%00%00%00%C3%85L%1E%C3%8B%00%00%02%C3%97IDATX%C2%85%C3%8D%C2%97KHUQ%14%C2%86%3F%C3%AD%C2%85%C2%94E%C2%91%10A!%C2%B7A%C2%B3%C2%A2%C3%87%20%1C%15YD%C2%83F%3D%08%C2%84%06%C2%95B%C2%93%C2%8A%C2%82K%C2%864%C2%912'Q%11%C2%91D%C3%8FA%60%C3%A8%24*z%C2%87%04%11%19I%10%C2%84%C3%A2E%08%22%22%C2%B3%14*%C3%AC%C3%B1%C3%87%C3%8EU%1C%C2%8E%C3%A7%C2%9E%C2%B3%C3%AF%C2%B9%C2%97h%C3%81%C3%82%7B%C3%B6%5Ek%C2%9D%7F%C3%BF%C3%BB%C3%AC%C2%B5%7F%C3%8B%24%C2%91%60%C3%AB%C2%81%2C0%23)%C3%90%C3%93F%C2%81%C2%9B%C3%80!%C2%9Fp%1F%C2%80w%C2%81A%C3%A0q%C2%89%00%C3%8E%02%C2%9A%C2%80%C3%B9%C3%80%C3%AB%C2%A4%C3%A0%C2%89%1E%05%C3%8B%C2%81%1B%C3%80%C3%85%C3%92%C3%A0%C2%A3%C3%9A%00N%C3%B0%09%C3%B6%01%C3%98%08%C3%B4%15%C2%8F%2B%C2%9D9%C2%80%C3%93%C2%80%C3%9D%C3%80%C2%A4%C2%98%0A%C3%AB%C3%ACo'%C3%B0%C3%A2_%03%C2%9C%0E%C2%AC%C3%B2d%C3%B3y%04%C3%80%C2%99%40%0BP%0BdBs%0D%40%5B%C2%B1%00%C3%9FX%C3%B14%C3%A6%00%C2%B5%03W%C2%81%05%C2%96%C3%AFN%C3%BC2%60%13%C3%B0%C2%AC%18px%C2%B2%16gY%3B%C3%A5G-%C2%A6%C3%9E%40%C2%B7%19%C3%80%5CL%C3%AEZ%C3%A0%5D%C3%84%C3%B8%7D%60%C3%B8%C3%AF%C2%93k3%C3%A6%C3%8D%C2%92%3E%26xC%20%C3%9Ey%C2%B7%C2%A43%C2%81%C3%A7~I%19I%C3%B5%1A3%22%C2%BC%C3%9A%C3%A6%C2%86%23%C3%9E%C3%B5U%C3%92%C2%95%60N%C2%90%C3%81%C2%B3%40w%02c%C3%A1%5E%C2%98%0Bl%C3%A3%C2%9F-%C3%8D%05%C2%98%C3%8B%C3%84%C2%B0%C2%B8%08%18%08%C2%8D-%07%C2%9E%00%C2%A7%C2%80Ga%06%C2%8B%C3%B5v%C2%8D%C2%B7L%0C%C2%83%C3%95y%C3%9EwAc%3BS%1Ef0%C2%B8%C2%B2%C2%A5yV%C3%9D%C2%95%C2%87%C2%91%C2%8C%1D4wK%0C%C3%99s%C2%BF%1D%C2%96%C2%B8%C3%AF0%C3%8A%5C%C3%9F%C3%AD%05%C2%B6%01%C3%A7%C2%A3V%C3%90(i%20%C2%8F%C3%97%C3%A5Y%C2%B5%C3%BB%0EkCc%1F%24%C2%B5%C2%A4%60%C3%90%C3%B9AIo%25U%16%C2%BB%C2%AD%C3%99%C3%80%C2%A6%C2%86%C3%81%C2%B4%C3%9BVeS%00%C2%AC0%C2%82%0E%C3%BB%C2%808%16%C3%83%5C%1A%C3%B7%01%C3%A8%C3%BC%C2%80%C2%A4%1E%C2%9F%3E%C2%B8%04%C3%B8T%C3%A0wT%0A%C3%BB%C2%82)%C2%95%C3%BF%C3%9A%C2%8A%05%C3%A8%C3%B2%C3%A7%C2%9A%C3%A0(%C3%94%26%C3%9B%C3%AE%C2%B8%C3%93%3F%3B%C3%AE%05i%C3%8C%15o%C2%B5%2B%C3%89%C2%B5%C2%84%11%C2%A0%07%C2%A8)%C2%A0%C2%96k%C3%BAO%C2%81%C3%AB%C2%A6%07%C2%8E8%01%C2%9D%06%C2%A0%0CP%C3%90%C2%9A%C2%ADOm0%C3%B6%C2%9C%C2%A2y%08%C3%9C2%C2%A5%1CgU6w%C3%9C%C2%94%C3%94T%60%3B%C2%B0%07%C3%98ose%C3%86%C3%AE%C2%A8%C2%8F%C3%A4wLm%01%C3%B6%01%C3%9F-%C3%B9%C2%B2%01%C3%AC%08%C3%84%C2%95%05%C3%A4XgL%C2%BD%1D%C3%80g%60sh%C3%9C5%C3%A8%C2%BD%C3%80%25%60%C2%A5%5D%18%1B%7D%C3%9AD%C2%A5%C2%A4%0EICv%C2%A1%C2%8FX%C2%9B%C2%A8%C2%8A%C2%88%3D!%C3%A9%5B%C2%82%C3%A0%C3%B8)iWDn%C2%8D%C3%95%C2%BDcu%16%C3%BF%26%2FE%1F%C2%9Bc%C2%85%C3%827%C2%87%C3%B3%7B%C2%92%C3%8E%25%C3%A4wI%3A%1D1%C3%AE%C2%94%C3%92%60x%3Cm%C2%B3%C2%BD-%C2%A9O%C3%92B%7B.%0F%C3%9C*%C2%AB%13rw%1A%C3%8B%5B%03c%2B%24%C2%BD%C2%97%C3%94Z*%C2%80%C3%B3%24%C3%B5J%C3%BA!%C3%A9%C2%A5%C3%9D%C2%9B%C3%8E%C2%9A%3Cr%C3%9Dw%7F%C3%92%C3%A2%C3%9Du%C3%B6%C3%8A~_%C2%934%25%1C%C3%AFsH%C3%B2Y%05Pg%1A%C3%8E)%18'%C3%BB%0B%C2%91%C3%B8N%C3%A9%C2%AC%C2%B1%7F%C3%96%C2%9C%C3%B6%7B0.%02%C3%B8%05%C3%8E%C2%BF%C3%A8%C3%AA!%C3%A9%C3%81%C3%8A%00%00%00%00IEND%C2%AEB%60%C2%82";

        }
    }
    var logoImage = signatureGroupe.add("image", undefined, File.decode(logoImage_imgString), { name: "logoImage" });

    var logoGroupe = signatureGroupe.add("group", undefined, { name: "logoGroupe" });
    logoGroupe.orientation = "column";
    logoGroupe.alignChildren = ["left", "center"];
    logoGroupe.spacing = 0;
    logoGroupe.margins = 0;

    var logoNom = logoGroupe.add("statictext", undefined, undefined, { name: "logoNom" });
    logoNom.text = scriptName + " " + version + " — " + date;

    var signature = logoGroupe.add("statictext", undefined, undefined, { name: "signature" });
    signature.text = "Jean loup Fusz —  www.jloupf.fr";
    signature.justify = "center";

    var boutonGroupe = deliverGlyphs.add("group", undefined, { name: "BoutonGroupe" });
    boutonGroupe.orientation = "column";
    boutonGroupe.alignChildren = ["center", "center"];
    boutonGroupe.spacing = 10;
    boutonGroupe.margins = 0;

    var ok = boutonGroupe.add("button", undefined, undefined, { name: "ok" });
    ok.text = __("OK");

    var cancel = boutonGroupe.add("button", undefined, undefined, { name: "cancel" });
    cancel.text = __("Cancel");

    var resultats = deliverGlyphs.show();
    if (resultats == true) {
        var beginId = premierGlyphID.text;
        var endId = dernierGlyphID.text;
        var reply = { beginGlyph: beginId, endGlyph: endId };
    } else {
        var reply = null;
        deliverGlyphs.close();
    }

    return (reply);
}

function endScreen(c, beginGlyph, endGlyph, noMore, timeDelivery) {

    var ok = new Window("dialog");
    ok.text = __("Success delivery!") + " - " + scriptName;
    ok.preferredSize.width = 400;
    ok.orientation = "column";
    ok.alignChildren = ["center", "center"];
    ok.spacing = 10;
    ok.margins = 16;

    var group1 = ok.add("group", undefined, { name: "group1" });
    group1.orientation = "row";
    group1.alignChildren = ["left", "center"];
    group1.spacing = 10;
    group1.margins = 0;

    var image1_imgString = "%C2%89PNG%0D%0A%1A%0A%00%00%00%0DIHDR%00%00%00(%00%00%00%1A%08%06%00%00%00%C3%85L%1E%C3%8B%00%00%02%C2%B0IDATX%C2%85%C3%8D%C2%97%5B%C2%88MQ%18%C3%87%7F%C3%A7%C3%A4%C2%92%0Cr%2B)b%5E%C2%BC%11g%1E4O%C3%A4%C2%92%3Cx%12)%C3%A5%C3%81%C3%A5%C2%94%12%C2%A2%26%24%2F%13%C3%B2%22%24%1D%09%C3%B1%C2%A0h%C3%A6E%123.II%C2%8EH)%C3%91%C2%A0%C2%94%24%C2%971%0A%C2%8D%C3%8B%C3%91%C2%A7%C3%BF%C2%A9%C3%95%C2%99%C2%B5%C3%B7Zg%C3%8E%0E%C3%BF%C3%9A%C3%AD%C2%BD%C3%97%5E%C3%9F%C2%B7%C3%BE%C3%BB%5B%C3%9Fm%C3%A5%08c)%C3%90%06%C2%8C%C2%89%C2%98%1B%C2%83~%C3%A02%C2%B0'fr%0C%C3%81n%C3%A0%3Dp'%23%C2%82%C3%A3%C2%80%C3%9D%C3%80T%C3%A0U%16%0A%C2%AF%03k%C2%B2P%24L%03*%C2%BAg%C2%82%C2%B9%C3%80%C3%B8%7FEp%08%C3%90%04l%06%C2%86%C2%A6%C3%8C%5B%C2%A2%7B'%C3%B0(%1B%C2%9Eq0%C2%82%C2%A3%C2%81%C3%B9z%0E%C3%A1%C3%81%C3%9F%26%C2%98%056%00%C3%A7%C2%B5m%C3%AE%C3%95%C2%93%C2%A0%C2%BB%C3%AE-n%04%C2%96~%16%02E%60%05%C3%90%2C%C2%B2%C2%86%C3%A7%01%C2%BD%C2%8B%C2%81%C2%B7%C2%9Eq%0B%C3%8A%3E%C2%9F%40%3B%C3%90%1B%C2%B8%C2%8A%C3%8E%7C%23c%C2%96%18%C3%AB%C2%8C%C3%B5h%C2%BC%0B%C3%98%C2%9F%40%C2%ACj%C3%81%3E%C3%8FZ%C3%9F%C2%80sI%16%3C%01%C2%94%03%7F%C3%AD%C3%A6%C3%82%C2%82%C3%AEF%C3%B0%C2%A3%C2%B6%C2%BA%5B%C2%96k%C3%96s%1Af%02%2Fk%C2%BE%C2%B7%00w%C2%81%C2%A3%C3%80%C3%AD%C2%80%7C%10F%C2%B0%C3%ACX%C2%B0%C3%AC%C2%906%0B%C2%96%12%14%C2%84%7C%C3%B0%C2%B4t%C3%A5I%C2%A8%24%C3%B6gs%12%C2%84o%25%C3%B8V%C3%81c%C3%BD%C3%A35.%C3%A1%12%7C%01L%C3%B7X%C3%900%19x%0Al%02N%C3%B9H%C3%AC%C2%94%C2%A0%C3%AFZ%C2%9D%40%C2%BC%C2%A4%C2%80q%C3%9F%C2%93%C3%9C%25%26%C2%8Aw%01o%C2%80Q)s%C2%A2Q%C3%90%C2%96%C2%BAhc%60%00%C3%95Cp%C2%84%C2%8C%C2%B37%C2%86%C3%84%C3%81%04%C3%8BY%20%C2%94%C2%B5%C3%98%07%C2%BDWQ%C3%90x%C3%89%C3%B1%C3%8Bz%08%1Av%00%0Fc%C3%B2%C3%A0l%C3%A0%C2%93g%C3%9C%7C%C2%B1%25A%C3%A6~d%C2%A7%C2%94%C2%86%C2%AFT%23%C3%A5%7FF%C2%A3%04%C3%B3%C2%8A%C2%BA%C2%A6A%C3%88%0E%C3%93%C3%AEX%25%C2%9A%C2%90%C2%B6%C3%80%60%60%C3%8A%0F%C2%A8%1AXJ%C3%B8l%C3%BE%02%C2%B4%C3%96%C2%A1%C3%8B%C2%92%C3%BE%3D%C3%A0%12%C3%B0%1A%C3%98%C3%A7s%C2%8B%18%C2%82%15%11r%C3%91%C2%AE%26v%C2%99%C2%ACg%C3%91z%13%C2%B8%C2%A2N9%0D%13%C3%B5%C3%AD%C2%90%3A%C2%A9%C2%91%C3%80Z%60%0B%C2%B0%5D%C3%9Fr%C2%B2n%7F%C2%8C%23%C2%9B%C2%A5V%02%C3%9B%C2%80%1F%12%3E%2B%C2%82%1D%C3%8E%C2%BC%C2%9C%C3%93%C2%8Eu%C2%A6%C3%A8%5B%07%7CQs%C3%A1%C3%82%C3%B2%C3%AFV%C3%A0%0C0O%05cy%04%C2%BF%3F%C3%89%C2%B2C%C3%B5%C2%B6W%C3%9BYq%2C%C3%A1%C3%A20%C3%B0%3D%C3%90p%C3%BC%026zd%5B%C2%A5%C2%B7Kzf%C3%85%C2%90%C3%B3a%C2%92%14%C2%99s%C3%97%C3%A2%1Ap2%20o%C3%A5%C3%B2%C2%98g%C2%BC%C2%A8%C3%83Y%26%C2%B8%0A%3C%03fHY%C3%9E%C2%A9%1E%0B%02%0B%C2%AC%C2%97%C2%95W9cv%C3%AEy'w%C3%8A%04S%14%C2%BD%3F%C2%81%C3%87%C2%AA%C2%9BF%C3%8E%C2%8E%C2%93!%C2%98%C2%AF%1E%C3%91%7C%2BgO%C3%B4%7C%11%18%5E%2B%C3%9CH%C2%B6%C2%B7zi%25%C3%90%C2%AA%C2%89%C3%B9%C3%A7%05U%C2%90XX%09%5C%C2%A4%C3%83%C2%9A%C3%B5~7%06%08%02%C2%BF%01W%18%C2%AA%C2%B1%C3%BB%C3%8Ak%C2%94%00%00%00%00IEND%C2%AEB%60%C2%82";
    if (parseInt(app.version) > 8) {
        var ui = app.generalPreferences.uiBrightnessPreference;
        if (ui < 0.51) {
            var image1_imgString = "%C2%89PNG%0D%0A%1A%0A%00%00%00%0DIHDR%00%00%00(%00%00%00%1A%08%06%00%00%00%C3%85L%1E%C3%8B%00%00%02%C3%97IDATX%C2%85%C3%8D%C2%97KHUQ%14%C2%86%3F%C3%AD%C2%85%C2%94E%C2%91%10A!%C2%B7A%C2%B3%C2%A2%C3%87%20%1C%15YD%C2%83F%3D%08%C2%84%06%C2%95B%C2%93%C2%8A%C2%82K%C2%864%C2%912'Q%11%C2%91D%C3%8FA%60%C3%A8%24*z%C2%87%04%11%19I%10%C2%84%C3%A2E%08%22%22%C2%B3%14*%C3%AC%C3%B1%C3%87%C3%8EU%1C%C2%8E%C3%A7%C2%9E%C2%B3%C3%AF%C2%B9%C2%97h%C3%81%C3%82%7B%C3%B6%5Ek%C2%9D%7F%C3%BF%C3%BB%C3%AC%C2%B5%7F%C3%8B%24%C2%91%60%C3%AB%C2%81%2C0%23)%C3%90%C3%93F%C2%81%C2%9B%C3%80!%C2%9Fp%1F%C2%80w%C2%81A%C3%A0q%C2%89%00%C3%8E%02%C2%9A%C2%80%C3%B9%C3%80%C3%AB%C2%A4%C3%A0%C2%89%1E%05%C3%8B%C2%81%1B%C3%80%C3%85%C3%92%C3%A0%C2%A3%C3%9A%00N%C3%B0%09%C3%B6%01%C3%98%08%C3%B4%15%C2%8F%2B%C2%9D9%C2%80%C3%93%C2%80%C3%9D%C3%80%C2%A4%C2%98%0A%C3%AB%C3%ACo'%C3%B0%C3%A2_%03%C2%9C%0E%C2%AC%C3%B2d%C3%B3y%04%C3%80%C2%99%40%0BP%0BdBs%0D%40%5B%C2%B1%00%C3%9FX%C3%B14%C3%A6%00%C2%B5%03W%C2%81%05%C2%96%C3%AFN%C3%BC2%60%13%C3%B0%C2%AC%18px%C2%B2%16gY%3B%C3%A5G-%C2%A6%C3%9E%40%C2%B7%19%C3%80%5CL%C3%AEZ%C3%A0%5D%C3%84%C3%B8%7D%60%C3%B8%C3%AF%C2%93k3%C3%A6%C3%8D%C2%92%3E%26xC%20%C3%9Ey%C2%B7%C2%A43%C2%81%C3%A7~I%19I%C3%B5%1A3%22%C2%BC%C3%9A%C3%A6%C2%86%23%C3%9E%C3%B5U%C3%92%C2%95%60N%C2%90%C3%81%C2%B3%40w%02c%C3%A1%5E%C2%98%0Bl%C3%A3%C2%9F-%C3%8D%05%C2%98%C3%8B%C3%84%C2%B0%C2%B8%08%18%08%C2%8D-%07%C2%9E%00%C2%A7%C2%80Ga%06%C2%8B%C3%B5v%C2%8D%C2%B7L%0C%C2%83%C3%95y%C3%9EwAc%3BS%1Ef0%C2%B8%C2%B2%C2%A5yV%C3%9D%C2%95%C2%87%C2%91%C2%8C%1D4wK%0C%C3%99s%C2%BF%1D%C2%96%C2%B8%C3%AF0%C3%8A%5C%C3%9F%C3%AD%05%C2%B6%01%C3%A7%C2%A3V%C3%90(i%20%C2%8F%C3%97%C3%A5Y%C2%B5%C3%BB%0EkCc%1F%24%C2%B5%C2%A4%60%C3%90%C3%B9AIo%25U%16%C2%BB%C2%AD%C3%99%C3%80%C2%A6%C2%86%C3%81%C2%B4%C3%9BVeS%00%C2%AC0%C2%82%0E%C3%BB%C2%808%16%C3%83%5C%1A%C3%B7%01%C3%A8%C3%BC%C2%80%C2%A4%1E%C2%9F%3E%C2%B8%04%C3%B8T%C3%A0wT%0A%C3%BB%C2%82)%C2%95%C3%BF%C3%9A%C2%8A%05%C3%A8%C3%B2%C3%A7%C2%9A%C3%A0(%C3%94%26%C3%9B%C3%AE%C2%B8%C3%93%3F%3B%C3%AE%05i%C3%8C%15o%C2%B5%2B%C3%89%C2%B5%C2%84%11%C2%A0%07%C2%A8)%C2%A0%C2%96k%C3%BAO%C2%81%C3%AB%C2%A6%07%C2%8E8%01%C2%9D%06%C2%A0%0CP%C3%90%C2%9A%C2%ADOm0%C3%B6%C2%9C%C2%A2y%08%C3%9C2%C2%A5%1CgU6w%C3%9C%C2%94%C3%94T%60%3B%C2%B0%07%C3%98ose%C3%86%C3%AE%C2%A8%C2%8F%C3%A4wLm%01%C3%B6%01%C3%9F-%C3%B9%C2%B2%01%C3%AC%08%C3%84%C2%95%05%C3%A4XgL%C2%BD%1D%C3%80g%60sh%C3%9C5%C3%A8%C2%BD%C3%80%25%60%C2%A5%5D%18%1B%7D%C3%9AD%C2%A5%C2%A4%0EICv%C2%A1%C2%8FX%C2%9B%C2%A8%C2%8A%C2%88%3D!%C3%A9%5B%C2%82%C3%A0%C3%B8)iWDn%C2%8D%C3%95%C2%BDcu%16%C3%BF%26%2FE%1F%C2%9Bc%C2%85%C3%827%C2%87%C3%B3%7B%C2%92%C3%8E%25%C3%A4wI%3A%1D1%C3%AE%C2%94%C3%92%60x%3Cm%C2%B3%C2%BD-%C2%A9O%C3%92B%7B.%0F%C3%9C*%C2%AB%13rw%1A%C3%8B%5B%03c%2B%24%C2%BD%C2%97%C3%94Z*%C2%80%C3%B3%24%C3%B5J%C3%BA!%C3%A9%C2%A5%C3%9D%C2%9B%C3%8E%C2%9A%3Cr%C3%9Dw%7F%C3%92%C3%A2%C3%9Du%C3%B6%C3%8A~_%C2%934%25%1C%C3%AFsH%C3%B2Y%05Pg%1A%C3%8E)%18'%C3%BB%0B%C2%91%C3%B8N%C3%A9%C2%AC%C2%B1%7F%C3%96%C2%9C%C3%B6%7B0.%02%C3%B8%05%C3%8E%C2%BF%C3%A8%C3%AA!%C3%A9%C3%81%C3%8A%00%00%00%00IEND%C2%AEB%60%C2%82";

        }
    }
    var image1 = group1.add("image", undefined, File.decode(image1_imgString), { name: "image1" });


    var statictext1 = group1.add("group");
    statictext1.orientation = "column";
    statictext1.alignChildren = ["left", "center"];
    statictext1.spacing = 0;
    if (noMore) {
        lastFound = ", " + __("last found.");
    } else {
        lastFound = "";
    }

    statictext1.add("statictext", undefined, __("%1 glyphs have been imported:", c), { name: "statictext1", multiline: true });
    statictext1.add("statictext", undefined, __("GID %1 to %2", beginGlyph, endGlyph) + lastFound, { name: "statictext1", multiline: true });
    statictext1.add("statictext", undefined, __("Total time: %1 s.", timeDelivery), { name: "statictext1", multiline: true });

    var button1 = ok.add("button", undefined, undefined, { name: "ok" });
    button1.text = __("Done");

    ok.show();


}

function continueUI(c, endGlyph, limiteTemps) {

    restGlyphs = endGlyph - c;
    restTime = (limiteTemps * restGlyphs) / c;
    restTimeInSeconds = Math.round(restTime / 1000);

    var continu = new Window("dialog");
    continu.text = __("Are you sure you want to continue?");
    continu.preferredSize.width = 400;
    continu.orientation = "column";
    continu.alignChildren = ["center", "center"];
    continu.spacing = 10;
    continu.margins = 16;

    var group1 = continu.add("group", undefined, { name: "group1" });
    group1.orientation = "row";
    group1.alignChildren = ["left", "center"];
    group1.spacing = 10;
    group1.margins = 0;

    var statictext1 = group1.add("group");
    statictext1.orientation = "column";
    statictext1.alignChildren = ["left", "center"];
    statictext1.spacing = 0;

    statictext1.add("statictext", undefined, __("The import has already been going on for 30 seconds."), { name: "statictext1", multiline: false });
    statictext1.add("statictext", undefined, __("%1 glyphs were imported. There are still %2 to be imported", c, restGlyphs), { name: "statictext1", multiline: false });
    statictext1.add("statictext", undefined, __("for an estimated %1 seconds.", restTimeInSeconds), { name: "statictext1", multiline: false });
    statictext1.add("statictext", undefined, __("Would you like to continue?"), { name: "statictext1", multiline: false });

    var boutons = continu.add("group", undefined, { name: "boutons" });
    boutons.orientation = "row";
    boutons.alignChildren = ["left", "center"];
    boutons.spacing = 10;
    boutons.margins = 0;

    var annuler = boutons.add("button", undefined, undefined, { name: "Cancel" });
    annuler.text = __("Cancel");

    var continuer = boutons.add("button", undefined, undefined, { name: "OK" });
    continuer.text = __("Continue");

    var reponse = continu.show();
    if (reponse == true) {
        reply = true;
    } else {
        reply = false;
    }

    return (reply);

}


function checkSetup() {

    if (app.documents.length < 1) {
        message = __("You must have a document open and the cursor somewhere in a text frame to use this script.");
        alertSetup(message);
        exit();
    }
    if (app.documents.item(0).pages.item(0).textFrames.length < 1) {
        message = __("You must have the cursor somewhere in a text frame to use this script. Create one to start.");
        alertSetup(message);
        exit();
    }
    if (app.selection.length !== 1) {
        message = __("You must have the cursor somewhere in a text frame to use this script. Click on a block with the text tool.");
        alertSetup(message);
        exit();
    }
    if (app.selection[0].constructor.name !== "InsertionPoint") {
        message = __("Please place the insertion point where you want to begin the import.");
        alertSetup(message);
        exit();
    }


}

function alertSetup(message) {

    var setUp = new Window("dialog");
    setUp.text = __("Caution") + " - " + scriptName;
    setUp.preferredSize.width = 400;
    setUp.orientation = "column";
    setUp.alignChildren = ["center", "center"];
    setUp.spacing = 10;
    setUp.margins = 16;

    var group1 = setUp.add("group", undefined, { name: "group1" });
    group1.orientation = "row";
    group1.alignChildren = ["left", "top"];
    group1.spacing = 10;
    group1.margins = 0;


    var image1_imgString = "%C2%89PNG%0D%0A%1A%0A%00%00%00%0DIHDR%00%00%00%1E%00%00%00%20%08%06%00%00%00%05%40%C3%88%7F%00%00%03pIDATH%C2%89%C3%A5%C2%97%C3%8Fk%1Ce%18%C3%87%3F%C3%8F%3B%C2%B3%C2%BF%C2%92%C3%9Dd%C3%93%C3%AC%C2%A6%C2%906%C2%B5%C2%B5%C3%95m)-%C2%B6%C2%A9%C2%B1%C2%A8%20*%C2%81z%C3%B2VZA%C2%A1B)%C2%88%20%1Ej%C3%80%C2%83%17-m%3D%C2%88%17E%7B%C2%99C%0F%C3%92S%C3%81%C2%93%C3%A0%7FPDD%C2%B18%15%0C%C2%8A'%C2%A5%C2%96%14%C2%8C%C2%BA%C2%99%C2%9D)%C3%AF%3B%C3%B3fg%C2%92%C3%8DlvY%C3%B1%C3%A0%17f%C3%A7%C3%BD%C3%B9%7C%C3%9F%C3%AF%C3%BB%C2%BE%C3%8F%C3%B3%C3%8C%C3%B2_A%C3%96%C2%BE%C3%9C7(%C2%B5%02%C3%8E%03%2F%03%C3%93%C3%80-%C3%A0%3D%C2%B7u%C3%AE%C3%87%C3%AD%1A%C2%90%3D%C3%AF%18%23%C2%83%40%10%C3%A73%C3%A0%13%C3%A0)%C3%A0%20%C3%B0%0A%C3%B0u%C3%A0%7B%C2%8F%0F%C2%BA%C3%BAAp%C2%81%C2%A8s%C3%9AL%C3%9Cq%04g%C3%B6Y%C2%A4X%C3%97%C3%95*p%23%C3%B0%C2%BD%C3%9A%C2%BFA%C3%9C%40%C3%94%07f%C3%92%C3%B4QT%C3%B3%04R%C3%9B%C2%8B3w%0A%C2%9CR%04%C3%A83%7B%7B%C3%B4%C3%84%C3%8A%C2%BDB%14V(TQ%C3%93%C2%8Fu%C3%9B%C3%9D%0A%C2%AA1%2FI%C3%AD%C3%8D%C3%80%C3%B7%C3%B6%C2%8E%C2%92%C3%B80a%C3%A7U%5Dp%C2%9A'%40%C2%9C%C2%AC%C2%91%C3%BA%C2%A3HiJ%C2%AB.%01WGG%C2%AC%C2%8A%C3%97%20%12%C2%A9%C3%8C%20%C2%B5%5E%5E%20%C2%A8%C3%A6%C2%82U%7D%3A%C3%B0%C2%BD%C2%A7GA%C3%BC%02a%C3%BBI3xf!%C3%9B%13u%C2%BA%C3%94%C3%A3%C2%B3Hu%C3%8EV%3F%0C%7CO%C3%88A%3Fb%17U%C3%B8%C3%94%18%C2%9E%C3%98%C2%8F%C2%94%C2%9B%09aH%C3%A7%C3%A7%C3%8F%09%C3%AE%5C'%C2%BA%C3%BFSWEs%01D%C3%A9-%C2%9FO%C3%BC%7CH%C3%85%C2%A2%5E'%5C%C2%9B%C3%93g%C3%AA4%C3%A7%C2%BBB%C2%83U%C2%A2%C2%BF%C3%AF%C3%AA%12%C3%A1%C2%9F%C2%BFv%C2%87%17'P%C3%B5%C2%83V%C3%A9%C3%A5%C3%80%C3%B7%C3%86%C2%87!%C2%9E%02%C2%B9D%C3%A2%C2%B3%C2%B8%5D%1B%C3%A2%14Sk%2Bf%26%C2%A9%C3%A9c%C3%A0%14%C2%B5%C3%AAY%60ipb%C3%A5%5E%22%C3%AA%C2%8C%C3%A1%C2%8E%C3%85%C3%84%C2%99%C2%BE%C2%A2f%C2%8C%C3%8Bn%25%C3%9B%C3%A7%14Q%C2%8D%C3%A3V%C3%B5%C3%85%C3%80%C3%B7v%0FB%C3%9C%22%C3%AC%5C%C3%80%C2%BA%C2%8Fr7%C2%8Fp%C3%8A%C3%89%C2%BB%C2%B4%C3%99%C3%A8d%C3%8BF%C2%B4%C3%B2V%C3%AE%C3%95%C2%9BX%C2%B9%1FC%C2%A4%C2%A4%C3%9C0%C2%97%C2%AA%17%24!%C2%B6%C3%AF%0CD%C2%A1f%C3%96C%C3%B7K%C2%81%C3%AF%C2%9D%C3%9C%0E%C3%B1%22a%C3%B0%C2%9C%C3%A9%C2%9Cy%C2%A2'%C2%A9%C2%81%C2%9B%10n%C3%9C%C3%AA%042%C2%BE%1B%19%C3%9Fe%C2%AB%C2%9B%C3%9Ck%23%C2%B1%C2%8B8%1F%19%25%C2%B5%7D%C3%A8%C2%80%C2%B1%25%C3%96%C2%B7%C2%BA%C2%87bk%C3%9C%C3%B8%C2%BD%C3%A1%C3%93%0A%C3%8E%C3%A4%11%C2%9F'%C3%AA%3C%C2%A2%C3%9DG'%C2%81%3C%C2%A8%C3%AACHu%0FR%C3%98%3A!%C3%A9sV%C3%B5%C2%96%C2%AD%5E%0D%7Co%7D%7B%C3%92%C3%84uD%5D6%C2%8D%3B%0E%23%C2%85j.%C2%B1%C2%8ETJ%C3%BB%C2%B6%C3%A4%C2%87%02%C3%958%1E%7B%01%C3%A8%C2%B0v%C2%B1%17%C3%B1%12Q8%19%C2%BB%C3%8F%C3%91%5Cc%3AT%06%C3%8B7%C3%A9%2C%C3%9F%24%C2%BCw%3B%7F%C2%ACSB5%C3%96%C2%B3%C3%99%5B%C2%81%C3%AF%C3%ADL%13%C3%97%10%C3%B5F%C2%BC%C3%82c%C2%A0%0A%C3%B9%C3%86%C3%825%08%C3%BE%C2%8A%C3%8B%C3%AD%C3%BB%C3%B9cM%C3%B6%3Ad%C2%8FDG%C2%A1%C3%97%C3%92%C3%84'M%C2%AE%C3%95%C3%8E%3Fq%C2%A0%C2%AF!%7D%C2%A1%C2%9C%5D%C3%8F%C2%9B%C2%BCl%16%C3%9A%0F%C2%A2%C2%90%C2%A9Cv%C3%90%22%C3%A6%16%C3%87%C2%98%C3%84%C3%B8d%C2%A5%C3%AF%C2%99Y%C3%A8L%C2%94%C3%8AF%C3%BD%C3%87%C2%BBc%C2%B68%C2%95V%C3%BC%C2%AD%C3%BE%C2%89%C3%9A%2B%C2%84%C3%B7%C2%BE%C3%8F%C2%A4%C2%BBQ%C3%80%C3%98%C3%BD%C3%A3%3Bk%C3%A9vZ%C3%B1%1D%C3%9C%C2%B1%2F%08VO%C2%85%C2%BF%C3%9D%22%C3%BC%C3%BD%2B%C2%BD%C3%84Q%C3%91%C3%86w%22%C3%96%C3%BD%0FD%C3%AF%C2%92%C2%B9%C3%95%C3%81%C3%AA%C2%8B%C2%88z%1FQ%2B%3A%C3%9F%12%C2%B6G%C3%B4%24%C2%A4N%C3%B9%07%C2%88%C2%9Eq%5B%C3%A7%C2%BEI%2B%C3%96h%13%C2%85K%C3%89%C2%97%C2%A2%0E%C3%90%3A%C3%AB%C3%B7%C2%B9%C3%9E%C3%9B%C3%82%0A%C3%B0%C2%8B%7B%C3%A0%C3%AC%C3%9D%C3%B4%C3%A0a%C3%BEIdPX%5C%1Ej%C3%9E%C2%A0%1F%C3%B4%23%C3%83%C3%BF%C2%93%C3%B8a%C3%AB%C3%94%1B%C3%9E%C2%B6M%C3%B7%C3%ABgc%C3%BB%C3%B0%00%1E%001%09%C3%A1d'%C3%85%C2%BD%C3%9E%00%00%00%00IEND%C2%AEB%60%C2%82";
    var image1 = group1.add("image", undefined, File.decode(image1_imgString), { name: "image1" });

    var statictext1 = group1.add("group");
    statictext1.orientation = "column";
    statictext1.alignChildren = ["left", "center"];
    statictext1.spacing = 0;

    statictext1.add("statictext", undefined, message, { name: "statictext1", multiline: true });

    var button1 = setUp.add("button", undefined, undefined, { name: "cancel" });
    button1.text = __("OK");

    setUp.show();


}



// #####################################
// YALT BLOCK | Thanks to Marc Autret ;-)
// #####################################
var L10N = L10N || (function(ln) {
    //======================================
    // <L10N> :: FRENCH_LOCALE :: GERMAN_LOCALE
    //======================================
    // Active font:  :: Police active :  :: Aktive Schriftart: 
    // Font family:  :: Famille de polices :  :: Schriftfamilie: 
    // Font style:  :: Style de police :  :: Schriftschnitt: 
    // First Glyph ID: :: Premier Glyph ID : :: Erste Glyph ID:
    // Specify the starting GID :: Spécifiez le GID de départ :: Geben Sie die Anfangs-GID an
    // Last Glyph ID: :: Dernier Glyph ID : :: Letzte Glyph ID:
    // Specify the end GID :: Spécifiez le GID de fin :: Geben Sie die End-GID an
    // OK :: OK :: OK
    // Cancel :: Annuler :: Abbrechen
    // Glyphs are on their way :: Les glyphes sont en cours de livraison :: Glyphen werden geliefert
    // Success delivery! :: Livraison terminée ! :: Lieferung durchfuhrt!
    // %1 glyphs have been imported: :: %1 glyphes ont été importés : :: %1 Glyphen wurden importiert:
    // GID %1 to %2 :: du GID %1 au %2 :: GID %1 bis %2
    // last found. :: dernier trouvé. :: , zuletzt gefunden
    // Total time: %1 s. :: Temps total : %1 s. :: Total Zeit: %1 S.
    // Done :: Terminer :: Ende
    // Caution :: Attention :: Vorsicht
    // You must have a document open and the cursor somewhere in a text frame to use this script. :: Vous devez avoir un document d'ouvert et être dans un bloc de texte pour utiliser ce script. :: Sie müssen ein Dokument geöffnet haben und sich in einem Textrahmen befinden, um dieses Skript verwenden zu können.
    // You must have the cursor somewhere in a text frame to use this script. Create one to start. :: Vous devez être dans un bloc de texte pour utiliser ce script. Créez-en un pour commencer. :: Sie müssen sich in einem Textrahmen befinden, um dieses Skript verwenden zu können. Erstellen Sie eine für den Anfang.
    // You must have the cursor somewhere in a text frame to use this script. Click on a block with the text tool. :: Vous devez être dans un bloc de texte pour utiliser ce script. Cliquez sur un bloc avec l'outil Texte. :: Sie müssen sich in einem Textrahmen befinden, um dieses Skript verwenden zu können. Klicken Sie mit dem Textwerkzeug auf einen Block.
    // Please place the insertion point where you want to begin the import. :: Veuillez placer le point d'insertion à l'endroit où vous souhaitez commencer l'importation. :: Bitte platzieren Sie die Einfügemarke dort, wo Sie mit dem Import beginnen möchten.
    // Are you sure you want to continue? :: Êtes-vous sûr de vouloir continuer ? :: Sind Sie sicher, dass Sie weitermachen wollen?
    // The import has already been going on for 30 seconds. :: L'importation dure déjà depuis trente secondes. :: Der Import läuft bereits seit 30 Sekunden.
    // %1 glyphs were imported. There are still %2 to be imported :: %1 glyphes ont été importés. Il en reste %2 à importer :: %1 Glyphen wurden importiert. Es müssen noch %2 importiert werden
    // for an estimated %1 seconds. :: pour une durée estimée à %1 secondes. :: für schätzungsweise %1 Sekunden.
    // Would you like to continue? :: Souhaitez-vous continuer ? :: Möchten Sie fortfahren?
    // Continue :: Continuer :: Fortfahren
    // Oops! We can't determine the style of the font used... Try another version of this font. :: Oooups! Nous n'arrivons pas à déterminer le style de la police utilisée… Essayez avec une autre version de cette police. :: Hoppla! Wir können den Stil der verwendeten Schriftart nicht bestimmen... Versuchen Sie eine andere Version dieser Schriftart.
    // </L10N>

    var CM = '// ',
        SP = ' :: ',
        BM = '<L10N>',
        EM = '</L10N>',
        NL = '\r';
    ln = ln || (function(lid) {
        for (var p in Locale)
            if (Locale[p] == lid) return (p);
    })(app.locale);
    var tb = (function(bdy) {
        var lines = (function() {
            var t = CM.length,
                ls = bdy.replace(/[\r\n]+[ \t]*/g, NL).split(NL),
                l, r = [];
            while (typeof(l = ls.shift()) != 'undefined') {
                if (l.indexOf(CM) != 0) continue;
                if (l.indexOf(EM) >= 0) break;
                if (l.indexOf(SP) < 0) continue;
                r.push(l.substr(t).split(SP));
            }
            while ((l = r.shift()) && (l[0] != BM));
            return l && [l].concat(r);
        })();
        //prompt( "YALT-to-JSXBIN Helper",'var lines='+lines.toSource()+';' );
        if (!lines) return {};
        var l = lines[0],
            c = (function() {
                for (var c = 1, sz = l.length; c < sz; ++c)
                    if (l[c] == ln) return c;
                return 0;
            })();
        if (!c) return {};
        var t, r = {},
            uEsc = function() { return String.fromCharCode(Number('0x' + arguments[1])); };
        while (l = lines.shift())(t = l[c]) && (r[l[0]] = t.replace(/\\u([0-9a-f]{4})/gi, uEsc));
        return r;
    })(arguments.callee.toString());
    __ = function(ks) {
        var r = (tb[ks] || ks),
            a = arguments,
            sz = a.length;
        return (sz < 1) ? r : r.replace(RegExp('%([1-' + sz + '])', 'g'), function(m, i) { return a[i]; });
    };
    return { locale: ln, version: 2.100723 };
})( /*'ENGLISH_LOCALE'*/ );


// #####################################
// END YALT
// #####################################


checkSetup();

app.doScript(main, ScriptLanguage.javascript, undefined, UndoModes.ENTIRE_SCRIPT, "DeliverGlyph");